import axios from 'axios';
import { getToken } from '../utils/tokenUtils';

const isProduction = process.env.NODE_ENV ? process.env.NODE_ENV == 'production': true;
const clusterMode = process.env.USE_IN_VAN_CLUSTER === 'true';
const baseUrl = (isProduction && clusterMode) ? '' : process.env.REACT_APP_PUBLIC_API_URL;

export const publicApi = axios.create({
    baseURL: `${baseUrl}/api/publicapi`,
});

publicApi.interceptors.request.use(async config => {
  const token = await getToken();
  const configWithToken = {
    ...config,
    headers: {
      'Authorization': `Bearer ${token}`
    }
  }
  return configWithToken
})

export const authApi = axios.create({
  baseURL: (isProduction && clusterMode) ? undefined : baseUrl,
  headers: {
    'Content-Type': 'application/x-www-form-urlencoded'
  }
});
