/** Transaction status enumeration */
export enum TransactionStatus {
    LOCAL = 'local',
    NEW = 'New',
    UPLOAD = 'Upload',
    PROCESSING = 'Processing',
    PROCESSED = 'Processed',
    REVIEW = 'Review',
    FAILED = 'Failed',
    NONE = 'NONE',
}

/** File type enumeration */
export enum FileType {
    JSON = 'json',
    PDF = 'pdf',
}

/** Skill object type */
export type Skill = {
    /** Skill id */
    id: string;
    /** Skill name */
    name: string;
    /** Skill type */
    type: string;
};

/** Transaction object type */
export type Transaction = {
    /** Transaction local uuid */
    uuid: string;
    /** Transaction mobile mode */
    isMobile?: boolean;
    /** Transaction id */
    transactionId?: string;
    /** Skill id specific for transactions */
    skillId?: string | null;
    /** Transaction status */
    status: TransactionStatus;

    /* params for transaction */
    /** Uploaded file */
    transactionFile?: File;
    /** File name uploaded by mobile capture */
    transactionMobileFileName?: string;
    /** Uploaded file url */
    transactionFileUrl?: string;
    /** Uploaded JSON file id */
    transactionFileId?: string;

    /* params for web verification */
    /** Review link */
    reviewLink?: string;

    /* params for classification */
    /** Result document class name */
    resultClassName?: string;

    /* params for file result */
    resultFiles?: ResultFile[]

    /** Deleting flag */
    deleting?: boolean;
};

/** Transaction object type */
export type ResultFile = {
    fileIndex?: number
    fileId: string,
    fileName: string,
    type: string
}
