import React from 'react';
import styles from './BrowseButtonComponent.module.scss';
import AddIcon from '@assets/icons/ic_add.svg';

interface BrowseButtonComponentProps {
    /** Text displayed on the button */
    text: string;
    /** Name of style class */
    buttonType?: 'default' | 'rounded';
    /** File input ref */
    hiddenFileInput: React.RefObject<HTMLInputElement>;
    /** Handler for input click */
    handleClick: () => void;
    /** Handler for file open */
    handleFile: (event: React.ChangeEvent<HTMLInputElement>) => void;
}

/**
 *  Component to render a styled button for browse documents
 */
function BrowseButtonComponent({
    text,
    buttonType = 'default',
    hiddenFileInput,
    handleClick,
    handleFile,
}: BrowseButtonComponentProps) {
    return (
        <>
            <input
                type="file"
                ref={hiddenFileInput}
                className={styles.input}
                accept=".jpg, .jpeg, .jpe, .jb2, .jbig2, .jp2, .j2k, .jpf, .jpx, .jpc, .bmp, .png, .pdf, .tiff, .tif, .gif, .html, .htm, .txt, .rtf, .odt, .doc, .docx, .docm"
                onChange={handleFile}
            />
            <button
                type="button"
                className={buttonType === 'rounded' ? styles.buttonRounded : styles.buttonDefault}
                onClick={handleClick}
            >
                {buttonType === 'rounded' ? <AddIcon className={styles.icon} /> : null}
                {text}
            </button>
        </>
    );
}

export default BrowseButtonComponent;
