import React, {useRef} from 'react';
import cn from 'classnames/bind';
import styles from './EditMenuComponent.module.scss';
 import { resource } from '@assets/text/resources';
import EditDotsIcon from '@assets/icons/ic_edit_dots.svg';
import LogOutIcon from '@assets/icons/ic_log_out.svg';
import CardViewIcon from '@assets/icons/ic_card_view.svg';
import ListViewIcon from '@assets/icons/ic_list_view.svg';
import {useOnClickOutside} from "@src/hooks/useClickOutside";

const cx = cn.bind(styles);

type EditMenuComponentProps = {
    /** Show drop down flag */
    isShow: boolean;
    /** Card view visibility flag */
    isCardView: boolean;
    /** Event handler for flip view */
    handleFlipView: () => void;
    /** Event handler for hide drop down */
    hideDropdown: (event: MouseEvent | TouchEvent) => void;
    /** Handler for log out click */
    handleLogOut: () => void;
    /** Event handler for show toggle */
    toggleShow: () => void;
};

/**
 *  Component to render a dropdown for display and select skills
 */
const EditMenuComponent = ({
    isShow,
    isCardView,
    handleFlipView,
    handleLogOut,
    hideDropdown,
    toggleShow,
}: EditMenuComponentProps) => {
    const ref = useRef(null);

    useOnClickOutside(ref, hideDropdown)

    return (
        <div className={styles.dropdown} ref={ref}>
            <button
                className={cx({dropButton:true, dropButtonActive: isShow})}
                onClick={toggleShow}
                type="button"
            >
                <span className={styles.dropTitle}>
                    <EditDotsIcon/>
                </span>
            </button>
            {isShow && <div className={styles.dropdownContent}>
                <button onClick={handleFlipView}>
                    <span className={styles.changeView}>
                        {isCardView? <ListViewIcon/>: <CardViewIcon/>}
                        {isCardView? resource.button.listView: resource.button.cardView}
                    </span>
                </button>
                <button>
                    <span className={styles.logOut} onClick={handleLogOut}>
                        <LogOutIcon/>
                        {resource.button.logOut}
                    </span>
                </button>
            </div>}
        </div>
    );
};

export default EditMenuComponent;
