import React from 'react';
import ReactDOM from 'react-dom';
import { resource } from '@assets/text/resources';
import IconError from '@assets/icons/ic_warn.svg';
import styles from './SessionExpiredModalComponent.module.scss';

interface SessionExpiredModalComponentProps {
    closeHandler: () => void;
    signInHandler: () => void;
}

/**
 *  Component to render a session expired modal window
 */
function SessionExpiredModalComponent({ closeHandler, signInHandler }: SessionExpiredModalComponentProps) {
    const parent = document.body as HTMLElement;

    return ReactDOM.createPortal(
        <div className={styles.backdrop} onClick={closeHandler}>
            <div className={styles.modal}>
                <div className={styles.title}>
                    <div className={styles.icon}>
                        <IconError/>
                    </div>
                    <span className={styles.titleText}>{resource.title.sessionExpired}</span>
                </div>
                <div className={styles.subtitle}>{resource.title.pleaseSignIn}</div>
                <div className={styles.footer}>
                    <button type="button" className={styles.button} onClick={signInHandler}>
                        {resource.button.signIn}
                    </button>
                </div>
            </div>
        </div>,
        parent,
    );
}

export default SessionExpiredModalComponent;
