import React, { useCallback, useRef } from 'react';
import { useDispatch } from 'react-redux';
import { v4 as uuid } from 'uuid';
import { createLocalTransactionRequest } from '@ducks/Transaction/actions';
import BrowseButtonComponent from '@commonComponents/BrowseButtonComponent/BrowseButtonComponent';
import { TransactionStatus } from '@api/types';

interface BrowseButtonContainerProps {
    /** Text displayed on the button */
    text: string;
    /** Name of style class */
    buttonType?: 'default' | 'rounded';
}

/**
 *  Component to render a styled button for browse documents
 */
const BrowseButtonContainer = ({ text, buttonType = 'default' }: BrowseButtonContainerProps) => {
    const hiddenFileInput = useRef<HTMLInputElement>(null);
    const dispatch = useDispatch();

    const handleClick = useCallback(() => {
        hiddenFileInput.current?.click();
    }, [hiddenFileInput]);

    const handleFile = useCallback(
        (event: React.ChangeEvent<HTMLInputElement>) => {
            const { files } = event.target;
            if (files && files.length > 0) {
                dispatch(
                    createLocalTransactionRequest({
                        transaction: {
                            uuid: uuid(),
                            status: TransactionStatus.LOCAL,
                            transactionFile: files[0],
                        },
                    }),
                );
                // eslint-disable-next-line no-param-reassign
                event.target.value = '';
            }
        },
        [dispatch],
    );

    return (
        <BrowseButtonComponent
            text={text}
            buttonType={buttonType}
            handleClick={handleClick}
            handleFile={handleFile}
            hiddenFileInput={hiddenFileInput}
        />
    );
};

export default BrowseButtonContainer;
