import React, { useCallback, useState } from 'react';
import { useSelector } from 'react-redux';
import SkillDropdownComponent from '@commonComponents/SkillDropdownComponent/SkillDropdownComponent';
import { Skill } from '@api/types';
import { skillsIsLoadingSelector } from '@ducks/Skill/selectors/skillsIsLoadingSelector';

type SkillDropdownContainerProps = {
    /** Available array of skills */
    skills: Array<Skill>;

    /** Selected skill id for current transaction */
    selectedSkillId?: string | null;

    /** Event handler for skill changes */
    handleChange: (skillId: string | null) => void;

    /** Disable flag for drop down */
    disabled?: boolean;
};

/**
 *  Component to render a dropdown for display and select skills
 */
const SkillDropdownContainer = ({
    skills,
    selectedSkillId = null,
    handleChange,
    disabled = false,
}: SkillDropdownContainerProps) => {
    const [show, setShow] = useState(false);
    const isLoading = useSelector(skillsIsLoadingSelector);
    const toggleShow = useCallback(() => {
        setShow(true);
    }, [setShow]);

    const hideDropdown = useCallback(
        () => {
            setShow(false);
        },
        [setShow],
    );

    const handleSkillChange = useCallback(
        (event: React.MouseEvent) => {
            const skillId = event.currentTarget.getAttribute('data-value');
            handleChange(skillId);
            setShow(false);
        },
        [handleChange, setShow],
    );

    return (
        <SkillDropdownComponent
            isShow={show}
            skills={skills}
            isLoading={isLoading}
            handleSkillChange={handleSkillChange}
            selectedSkillId={selectedSkillId}
            hideDropdown={hideDropdown}
            toggleShow={toggleShow}
            disabled={disabled}
        />
    );
};

export default SkillDropdownContainer;
