import { Type } from './actionTypes';
import { MobileCaptureActionTypes } from '@ducks/Mobile/actions/MobileCaptureActions';

export const initialState: MobileCaptureState = {
    /** Qr code visibility flag */
    isVisible: false,
    /** Transaction id */
    transactionId: '',
    /** Url link */
    mobileInputLink: '',
};

/**
 * QR Code reducer state type
 */
export interface MobileCaptureState {
    isVisible: boolean;
    transactionId: string;
    mobileInputLink: string
}

/**
 * Mobile capture reducer
 * @param state
 * @param action
 */
export const reducer = (state = initialState, action: MobileCaptureActionTypes): MobileCaptureState => {
    switch (action.type) {
        case Type.SHOW_QR_CODE: {
            return {
                ...state,
                isVisible: true,
                transactionId: action.payload.transactionId,
            };
        }

        case Type.HIDE_QR_CODE: {
            return {
                ...state,
                isVisible: false,
                transactionId: '',
                mobileInputLink: ''
            };
        }

        case Type.GET_MOBILE_LINK_SUCCESS: {
            return {
                ...state,
                transactionId: action.payload.transactionId,
                mobileInputLink: action.payload.mobileInputLink
            };
        }
        default:
            return state;
    }
};
