import { runSaga } from 'redux-saga';
import api from '../../../api/skillService';
import { getSkillsError, getSkillsStart, getSkillsSuccess, SkillActionTypes } from '../actions/skillActions';
import getSkillsSaga from './requestSkillsSaga';
import { resource } from '../../../assets/text/resources';

describe('Get skills sagas tests', () => {
    jest.spyOn(console, 'error').mockImplementation();
    it('Get skills success', async () => {
        const dispatched: Array<SkillActionTypes> = [];
        const dummyData = {
            data: [
                { id: 'id-1', name: 'skill name 1', type: 'skill type' },
                { id: 'id-2', name: 'skill name 2', type: 'skill type' },
            ],
            status: 200,
            statusText: 'OK',
            headers: {},
            config: {},
        };
        const getSkills = jest.spyOn(api, 'getSkills').mockImplementation(() => Promise.resolve(dummyData));

        await runSaga(
            {
                dispatch: (action: SkillActionTypes) => dispatched.push(action),
            },
            getSkillsSaga,
        ).toPromise();

        expect(dispatched).toContainEqual(getSkillsStart());
        expect(dispatched).toContainEqual(
            getSkillsSuccess({
                skills: [
                    { id: 'id-1', name: 'skill name 1', type: 'skill type' },
                    { id: 'id-2', name: 'skill name 2', type: 'skill type' },
                ],
            }),
        );
        expect(getSkills).toHaveBeenCalled();
    });

    it('Get skills failed', async () => {
        const dispatched: Array<SkillActionTypes> = [];
        const getSkills = jest.spyOn(api, 'getSkills').mockImplementation(() => Promise.reject());

        await runSaga(
            {
                dispatch: (action: SkillActionTypes) => dispatched.push(action),
            },
            getSkillsSaga,
        ).toPromise();

        expect(dispatched).toContainEqual(getSkillsStart());
        expect(dispatched).toContainEqual(
            getSkillsError({
                errorText: resource.error.getSkillsFailed,
            }),
        );
        expect(getSkills).toHaveBeenCalled();
    });
});
