import { call, put } from 'redux-saga/effects';
import { getSkillsError, getSkillsStart, getSkillsSuccess } from '../actions/skillActions';
import skillService, { GetSkillsResponse } from '../../../api/skillService';
import { resource } from '../../../assets/text/resources';
import { SagaIterator } from 'redux-saga';

export default function* requestSkillsSaga(): SagaIterator {
    try {
        yield put(getSkillsStart());

        const response: GetSkillsResponse = yield call(skillService.getSkills);
        response.data.sort((prevSkill, nextSkill) => {
            const prevSkillName = prevSkill.name.toLowerCase();
            const nextSkillName = nextSkill.name.toLowerCase();
            if (prevSkillName < nextSkillName) return -1;
            if (prevSkillName > nextSkillName) return 1;
            return 0;
        });
        yield put(
            getSkillsSuccess({
                skills: response.data,
            }),
        );
    } catch (error) {
        console.error(resource.error.getSkillsFailed);
        console.error(error);
        yield put(
            getSkillsError({
                errorText: resource.error.getSkillsFailed,
            }),
        );
    }
}
