import MockFile from '../../../utils/mockFileUtil';
import {
    createTransactionError,
    createTransactionRequest,
    createTransactionStart,
    createTransactionSuccess,
} from './createTransactionActions';
import { Type } from '../actionTypes';
import { TransactionStatus } from '../../../api/types';

const testFile = MockFile({
    type: 'image/png',
    size: 50000,
});

describe('Create transaction action tests', () => {
    it('Create transaction request', () => {
        const expectedAction = {
            type: Type.CREATE_TRANSACTION_REQUEST,
            payload: {
                skillId: 'skill-id',
                transaction: {
                    uuid: 'uuid-1',
                    status: TransactionStatus.LOCAL,
                    transactionFile: testFile,
                },
            },
        };
        expect(
            createTransactionRequest({
                skillId: 'skill-id',
                transaction: {
                    uuid: 'uuid-1',
                    status: TransactionStatus.LOCAL,
                    transactionFile: testFile,
                },
            }),
        ).toEqual(expectedAction);
    });

    it('Create transaction start', () => {
        const expectedAction = {
            type: Type.CREATE_TRANSACTION_START,
            payload: {
                uuid: 'uuid-1',
                skillId: 'skill-id',
            },
        };
        expect(
            createTransactionStart({
                uuid: 'uuid-1',
                skillId: 'skill-id',
            }),
        ).toEqual(expectedAction);
    });

    it('Create transaction success', () => {
        const expectedAction = {
            type: Type.CREATE_TRANSACTION_SUCCESS,
            payload: {
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
            },
        };
        expect(
            createTransactionSuccess({
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
            }),
        ).toEqual(expectedAction);
    });
    it('Create transaction failed', () => {
        const expectedAction = {
            type: Type.CREATE_TRANSACTION_ERROR,
            payload: {
                uuid: 'uuid-1',
                errorText: 'error',
            },
        };
        expect(
            createTransactionError({
                uuid: 'uuid-1',
                errorText: 'error',
            }),
        ).toEqual(expectedAction);
    });
});
