import {
    getTransactionError,
    getTransactionRepeat,
    getTransactionRequest,
    getTransactionStart,
    getTransactionStop,
    getTransactionSuccess,
} from './getTransactionActions';
import { Type } from '../actionTypes';
import { TransactionStatus } from '../../../api/types';

describe('Get transaction status action tests', () => {
    it('Get transaction status request', () => {
        const expectedAction = {
            type: Type.GET_TRANSACTION_REQUEST,
            payload: {
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
                skillId: 'skill-id',
            },
        };
        expect(
            getTransactionRequest({
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
                skillId: 'skill-id',
            }),
        ).toEqual(expectedAction);
    });

    it('Get transaction status start', () => {
        const expectedAction = {
            type: Type.GET_TRANSACTION_START,
            payload: {
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
                skillId: 'skill-id',
            },
        };
        expect(
            getTransactionStart({
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
                skillId: 'skill-id',
            }),
        ).toEqual(expectedAction);
    });

    it('Get transaction status stop', () => {
        const expectedAction = {
            type: Type.GET_TRANSACTION_STOP,
            payload: {
                transactionId: 'transaction-id',
            },
        };
        expect(
            getTransactionStop({
                transactionId: 'transaction-id',
            }),
        ).toEqual(expectedAction);
    });

    it('Get transaction status repeat', () => {
        const expectedAction = {
            type: Type.GET_TRANSACTION_REPEAT,
            payload: {
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
            },
        };
        expect(
            getTransactionRepeat({
                uuid: 'uuid-1',
                transactionId: 'transaction-id',
            }),
        ).toEqual(expectedAction);
    });

    it('Get transaction status success', () => {
        const expectedAction = {
            type: Type.GET_TRANSACTION_SUCCESS,
            payload: {
                uuid: 'uuid-1',
                status: 'Review',
                reviewLink: 'link',
            },
        };
        expect(
            getTransactionSuccess({
                uuid: 'uuid-1',
                status: TransactionStatus.REVIEW,
                reviewLink: 'link',
            }),
        ).toEqual(expectedAction);
    });
    it('Get transaction status failed', () => {
        const expectedAction = {
            type: Type.GET_TRANSACTION_ERROR,
            payload: {
                errorText: 'error',
            },
        };
        expect(
            getTransactionError({
                errorText: 'error',
            }),
        ).toEqual(expectedAction);
    });
});
