import { runSaga } from 'redux-saga';
import { createLocalTransactionError, createLocalTransactionSuccess, TransactionActionTypes } from '../actions';
import MockFile from '../../../utils/mockFileUtil';
import createLocalTransactionSaga from './createLocalTransactionSaga';
import { Type } from '../actionTypes';
import { resource } from '../../../assets/text/resources';
import { TransactionStatus } from '../../../api/types';

describe('Create local transaction sagas tests', () => {
    jest.spyOn(console, 'error').mockImplementation();
    it('Create local transaction success', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const testFile = MockFile({
            type: 'image/png',
            size: 50000,
        });

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            createLocalTransactionSaga,
            {
                type: Type.CREATE_LOCAL_TRANSACTION_REQUEST,
                payload: {
                    transaction: {
                        uuid: 'uuid-1',
                        transactionFile: testFile,
                        status: TransactionStatus.LOCAL,
                    },
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            createLocalTransactionSuccess({
                transaction: {
                    uuid: 'uuid-1',
                    transactionFile: testFile,
                    status: TransactionStatus.LOCAL,
                },
            }),
        );
    });

    it('Create local transaction failed - unsupported file type', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const testFile = MockFile({
            type: 'application/msword',
            size: 50000,
        });

        await runSaga(
            {
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            createLocalTransactionSaga,
            {
                type: Type.CREATE_LOCAL_TRANSACTION_REQUEST,
                payload: {
                    transaction: {
                        uuid: 'uuid-1',
                        transactionFile: testFile,
                        status: TransactionStatus.LOCAL,
                    },
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            createLocalTransactionError({
                errorText: resource.error.unsupportedFileFormat,
            }),
        );
    });
});
