import { put } from 'redux-saga/effects';
import mime from 'mime-types';
import { createLocalTransactionError, createLocalTransactionRequest, createLocalTransactionSuccess } from '../actions';
import { resource } from '../../../assets/text/resources';
import { SagaIterator } from 'redux-saga';

export default function* createLocalTransactionSaga({
    payload,
}: ReturnType<typeof createLocalTransactionRequest>): SagaIterator {
    if (!payload.transaction.transactionFile && payload.transaction.isMobile) {
        yield put(createLocalTransactionSuccess(payload));
    } else {
        if (payload.transaction.transactionFile) {
            try {
                if(payload.transaction.transactionFile.type) {
                    const isAvailableMime = ['pdf', 'jpg', 'jpeg', 'tiff', 'tif', 'gif', 'x-jbig2', 'jp2', 'bmp', 'png', 'html', 'htm',
                        'txt', 'rtf', 'odt', 'doc', 'docx', 'docm', true]
                      .includes(mime.extension(payload.transaction.transactionFile.type))
                    if(!isAvailableMime) {
                        throw new Error()
                    }
                } else {
                    const fileExt = payload.transaction.transactionFile.name.split('.').pop();
                    if(!fileExt || !['pdf', 'jpg', 'jpeg', 'tiff', 'tif', 'gif', 'jbig2', 'jpe', 'jb2', 'jp2', 'j2k', 'jpf', 'jpx', 'jpc', 'jp2', 'bmp', 'png',
                        'html', 'htm', 'txt', 'rtf', 'odt', 'doc', 'docx', 'docm']
                      .includes(fileExt)) {
                        throw new Error()
                    }
                }
                yield put(createLocalTransactionSuccess(payload));
            } catch (error) {
                yield put(createLocalTransactionError({ errorText: resource.error.unsupportedFileFormat }));
            }
        } else {
            yield put(createLocalTransactionError({ errorText: resource.error.otherError }));
        }
    }
}
