import { call, put, race, take } from 'redux-saga/effects';
import transactionService, {
    CreateTransactionRequestData,
    CreateTransactionResponse,
} from '../../../api/transactionService';
import {
    createTransactionError,
    createTransactionRequest,
    createTransactionStart,
    createTransactionSuccess,
    DeleteTransactionActionTypes,
} from '../actions';
import { resource } from '../../../assets/text/resources';
import { Type } from '../actionTypes';
import { SagaIterator } from 'redux-saga';
import { qrCodeShow } from '@ducks/Mobile/actions/MobileCaptureActions';

export default function* createMobileTransactionSaga({
    payload,
}: ReturnType<typeof createTransactionRequest>): SagaIterator {
    try {
        yield put(
            createTransactionStart({
                uuid: payload.transaction.uuid,
                skillId: payload.skillId,
            }),
        );

        const data: CreateTransactionRequestData = {
            skillId: payload.skillId,
        };

        const raceResult: { res: any; cancel: any } = yield race({
            res: call(transactionService.createTransaction, data),
            cancel: take(
                (action: DeleteTransactionActionTypes) =>
                    action.type === Type.DELETE_TRANSACTION_SUCCESS && action.payload.uuid === payload.transaction.uuid,
            ),
        });
        if (raceResult.cancel) {
            return;
        }
        const response: CreateTransactionResponse = raceResult.res;
        if (response.data.transactionId) {
            yield put(
                qrCodeShow({
                    transactionId: response.data.transactionId,
                }),
            );
        }
        yield put(
            createTransactionSuccess({
                uuid: payload.transaction.uuid,
                transactionId: response.data.transactionId,
            }),
        );
    } catch (error) {
        console.error(resource.error.createTransactionFailed);
        console.error(error);
        yield put(
            createTransactionError({
                uuid: payload.transaction.uuid,
                errorText: resource.error.createTransactionFailed,
            }),
        );
    }
}
