import { call, put, race, take } from 'redux-saga/effects';
import transactionService, {
    CreateTransactionLaunchRequestData,
    CreateTransactionResponse,
} from '../../../api/transactionService';
import {
    createTransactionError,
    createTransactionRequest,
    createTransactionStart,
    createTransactionSuccess,
    DeleteTransactionActionTypes,
} from '../actions';
import { resource } from '../../../assets/text/resources';
import { Type } from '../actionTypes';
import { SagaIterator } from 'redux-saga';

export default function* createTransactionSaga({ payload }: ReturnType<typeof createTransactionRequest>): SagaIterator {
    try {
        if (!payload.transaction.transactionFile) {
            throw new Error('File not exist in transaction');
        }
        yield put(
            createTransactionStart({
                uuid: payload.transaction.uuid,
                skillId: payload.skillId,
            }),
        );

        const formData = new FormData();
        formData.append('Files', payload.transaction.transactionFile, payload.transaction.transactionFile.name);
        const data: CreateTransactionLaunchRequestData = {
            skillId: payload.skillId,
            files: formData,
        };

        const raceResult: { res: any; cancel: any } = yield race({
            res: call(transactionService.createTransactionLaunch, data),
            cancel: take(
                (action: DeleteTransactionActionTypes) =>
                    action.type === Type.DELETE_TRANSACTION_SUCCESS && action.payload.uuid === payload.transaction.uuid,
            ),
        });
        if (raceResult.cancel) {
            return;
        }
        const response: CreateTransactionResponse = raceResult.res;
        yield put(
            createTransactionSuccess({
                uuid: payload.transaction.uuid,
                transactionId: response.data.transactionId,
            }),
        );
    } catch (error) {
        console.error(resource.error.createTransactionFailed);
        console.error(error);
        yield put(
            createTransactionError({
                uuid: payload.transaction.uuid,
                errorText: resource.error.createTransactionFailed,
            }),
        );
    }
}
