import { runSaga } from 'redux-saga';
import transactionService from '../../../api/transactionService';
import deleteTransactionSaga from './deleteTransactionSaga';
import { deleteTransactionError, deleteTransactionSuccess, TransactionActionTypes } from '../actions';
import { Type } from '../actionTypes';
import { resource } from '../../../assets/text/resources';

describe('Delete transaction sagas tests', () => {
    jest.spyOn(console, 'error').mockImplementation();
    it('Delete transaction success', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const dummyTransaction = {
            data: {},
            status: 200,
            statusText: 'OK',
            headers: {},
            config: {},
        };
        const deleteTransaction = jest
            .spyOn(transactionService, 'deleteTransaction')
            .mockImplementation(() => Promise.resolve(dummyTransaction));
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        status: 'Review',
                    },
                },
            },
            allIds: ['uuid-1'],
        };

        await runSaga(
            {
                getState: () => fakeStore,
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            deleteTransactionSaga,
            {
                type: Type.DELETE_TRANSACTION_REQUEST,
                payload: {
                    uuid: 'uuid-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            deleteTransactionSuccess({
                uuid: 'uuid-1',
            }),
        );
        expect(deleteTransaction).toHaveBeenCalledWith('transaction-id-1');
    });

    it('Delete transaction failed', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const deleteTransaction = jest
            .spyOn(transactionService, 'deleteTransaction')
            .mockImplementation(() => Promise.reject());
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        status: 'Review',
                    },
                },
            },
            allIds: ['uuid-1'],
        };

        await runSaga(
            {
                getState: () => fakeStore,
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            deleteTransactionSaga,
            {
                type: Type.DELETE_TRANSACTION_REQUEST,
                payload: {
                    uuid: 'uuid-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            deleteTransactionError({
                uuid: 'uuid-1',
                errorText: resource.error.deleteTransactionFailed,
            }),
        );
        expect(deleteTransaction).toHaveBeenCalledWith('transaction-id-1');
    });

    it('Delete local transaction success', async () => {
        const dispatched: Array<TransactionActionTypes> = [];
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        status: 'New',
                    },
                },
            },
            allIds: ['uuid-1'],
        };

        await runSaga(
            {
                getState: () => fakeStore,
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            deleteTransactionSaga,
            {
                type: Type.DELETE_TRANSACTION_REQUEST,
                payload: {
                    uuid: 'uuid-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            deleteTransactionSuccess({
                uuid: 'uuid-1',
            }),
        );
    });
});
