import { runSaga } from 'redux-saga';
import transactionService from '../../../api/transactionService';
import downloadTransactionSaga from './downloadTransactionSaga';
import {
    downloadTransactionError,
    downloadTransactionStart,
    downloadTransactionSuccess,
    TransactionActionTypes,
} from '../actions';
import { Type } from '../actionTypes';
import { resource } from '../../../assets/text/resources';
import { TransactionStatus } from '../../../api/types';

describe('Download transaction file sagas tests', () => {
    jest.spyOn(console, 'error').mockImplementation();
    it('Download transaction file success', async () => {
        const dispatched = [] as Array<TransactionActionTypes>;
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        resultFiles: [{
                            fileId: 'file-id-1',
                            fileName: 'file-name-1',
                            type: "json"
                        }],
                        status: TransactionStatus.PROCESSED,
                    },
                },
            },
            allIds: ['uuid-1'],
        };
        const dummyData = {
            data: JSON.stringify({
                test1: 'test1',
                test2: 'test2',
            }),
            status: 200,
            statusText: 'OK',
            headers: {},
            config: {},
        };
        const downloadFile = jest
            .spyOn(transactionService, 'downloadFile')
            .mockImplementation(() => Promise.resolve(dummyData));

        await runSaga(
            {
                getState: () => fakeStore,
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            downloadTransactionSaga,
            {
                type: Type.DOWNLOAD_TRANSACTION_FILE_REQUEST,
                payload: {
                    uuid: 'uuid-1',
                    fileId: 'file-id-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            downloadTransactionStart({
                uuid: 'uuid-1',
                fileId: 'file-id-1',
            }),
        );
        expect(dispatched).toContainEqual(
            downloadTransactionSuccess({
                uuid: 'uuid-1',
                fileId: 'file-id-1',
            }),
        );
        expect(downloadFile).toHaveBeenCalledWith('transaction-id-1', 'file-id-1');
    });

    it('Download transaction file failed', async () => {
        const dispatched = [] as Array<TransactionActionTypes>;
        const fakeStore = {
            transactionsStore: {
                byId: {
                    'uuid-1': {
                        uuid: 'uuid-1',
                        transactionId: 'transaction-id-1',
                        transactionFileId: 'file-id-1',
                        status: TransactionStatus.PROCESSED,
                    },
                },
            },
            allIds: ['uuid-1'],
        };
        jest.spyOn(transactionService, 'downloadFile').mockImplementation(() => Promise.reject());

        await runSaga(
            {
                getState: () => fakeStore,
                dispatch: (action: TransactionActionTypes) => dispatched.push(action),
            },
            downloadTransactionSaga,
            {
                type: Type.DOWNLOAD_TRANSACTION_FILE_REQUEST,
                payload: {
                    uuid: 'uuid-1',
                    fileId: 'file-id-1',
                },
            },
        ).toPromise();

        expect(dispatched).toContainEqual(
            downloadTransactionStart({
                uuid: 'uuid-1',
                fileId: 'file-id-1',
            }),
        );
        expect(dispatched).toContainEqual(
            downloadTransactionError({
                uuid: 'uuid-1',
                errorText: resource.error.downloadResultFileFailed,
                fileId: 'file-id-1',
            }),
        );
    });
});
