import React, {useState} from 'react';
import NoImageIcon from '@assets/icons/ic_no_image.svg';
import EmptyDocIcon from '@assets/icons/ic_emptyDoc.svg';
import VerificationIcon from '@assets/icons/ic_verification.svg';
import styles from './PreviewComponent.module.scss';
import { Transaction, TransactionStatus } from '@api/types';

type PreviewComponentProps = {
    /** Transaction object */
    transaction: Transaction;
};

/**
 *  Component to render preview image for document card
 */
function PreviewComponent({ transaction }: PreviewComponentProps) {
    const [isError, setIsError] = useState<boolean>(false)

    const errorHandler = ()=> {
        setIsError(true);
    }

    if (transaction.reviewLink) {
        return <VerificationIcon className={styles.verifiIcon} />;
    }

    if (transaction.transactionFile) {
        if (isError) {
            return (
                <div>
                    <EmptyDocIcon className={styles.emptyPictureIcon}/>
                </div>
            );
        }
        return (
            <div className={styles.pictureContainer}>
                <img className={styles.picture}
                     src={URL.createObjectURL(transaction.transactionFile)} alt=''
                     onError={errorHandler}/>
            </div>
        );
    }

    if([TransactionStatus.PROCESSING, TransactionStatus.PROCESSED].includes(transaction.status)) {
        return (
            <div>
                <EmptyDocIcon className={styles.emptyPictureIcon} />
            </div>
        );
    }

    return (
        <div className={styles.noPicture}>
            <NoImageIcon className={styles.noPictureIcon} />
        </div>
    );
}

export default React.memo(PreviewComponent);
