import React, {useEffect, useState} from 'react';
import { useHistory } from 'react-router-dom';
import { useDispatch, useSelector } from 'react-redux';

import LoginPageComponent from './components/LoginPageComponent';
import { authCodeRequest } from '@ducks/Auth/actions/AuthActions';
import { authSelector } from '@ducks/Auth/selectors/authSelector';
import {
    //deleteStoredPkce,
    getStoredPkce,
    getToken,
    setStoredPkce,
} from '@utils/tokenUtils';
import getPkce from 'oauth-pkce';

const isProduction = process.env.NODE_ENV ? process.env.NODE_ENV == 'production': true;
const clusterMode = process.env.USE_IN_VAN_CLUSTER === 'true';
const localUrl = `${window.location.protocol}//${window.location.hostname}` + (window.location.port ? `:${window.location.port}` : '')
const baseUrl = (isProduction && clusterMode)
    ? localUrl
    : process.env.REACT_APP_PUBLIC_API_URL;

/**
 *  Container to render a Login Page component
 */
function LoginPageContainer() {
    const dispatch = useDispatch();
    const history = useHistory();

    const authState = useSelector(authSelector);
    const [signIn, setSignIn] = useState(false);

    const generatePkce = (callback?: (data: { verifier: string, challenge: string }) => void)=>{
        getPkce(50, (_, { verifier, challenge }) => {
            setStoredPkce(JSON.stringify({ verifier, challenge }));
            if(callback!== undefined) {
                callback({verifier, challenge})
            }
        })
    }

    const redirectToOAuth = (data: { verifier: string, challenge: string })=>{
        console.log(baseUrl);
        let url = new URL(`${baseUrl}/auth2/connect/authorize`);
        url.searchParams.append('client_id', process.env.REACT_APP_CLIENT_ID ?? '');
        url.searchParams.append('scope', process.env.REACT_SCOPE ?? '');
        url.searchParams.append('redirect_uri', `${localUrl}/try-any-skill/` ?? '');
        url.searchParams.append('response_type', 'code');
        url.searchParams.append('code_challenge', data.challenge ?? '');
        url.searchParams.append('code_challenge_method', 'S256');
        url.searchParams.append('productId', process.env.REACT_APP_PRODUCT_ID ?? '');
        console.log(url.toString());
        window.location.replace(url.toString());
    }

    useEffect(() => {
        if(signIn) {
            getStoredPkce().then((storage) => {
                if (!storage) {
                    generatePkce(redirectToOAuth);
                } else {
                    const storedData = JSON.parse(storage);
                    redirectToOAuth(storedData)
                }
                setSignIn(false);
            })
        }
    });

    useEffect(() => {
        const code = new URLSearchParams(window.location.search).get("code")
        getStoredPkce().then((storage) => {
            if (storage) {
                const storageData = JSON.parse(storage ?? '');
                if (code) {
                    dispatch(
                        authCodeRequest({
                            code_verifier: storageData.verifier ?? '',
                            code: code ?? '',
                        }),
                    );
                }
            }
        })
    })

    const onSignIn = async () => {
        setSignIn(true);
    };

    useEffect(() => {
        getToken().then((token) => {
            if (token) history.push('/');
        });
    }, [authState.isAuth]);

    return <LoginPageComponent isLoading={authState.isLoading} onSignIn={onSignIn} />;
}

export default LoginPageContainer;
