import React from 'react';
import styles from './TableComponent.module.scss';
import DeleteIcon from '@assets/icons/ic_delete.svg';
import { TransactionState } from '@ducks/Transaction/reducer';
import TableRowComponent from '../TableRowComponent/TableRowComponent';
import { resource } from '@assets/text/resources';
import { Skill, Transaction } from '@api/types';

interface TableComponentProperties {
    /** Transactions (normalized object) */
    transactions: TransactionState;
    /** Skills */
    skills: Array<Skill>;
    /** Handler for skill change */
    handleSkillChange: (transaction: Transaction, skillId: string | null) => void;
    /** Handler for delete transaction */
    handleDelete: (transaction: Transaction) => void;
    /** Handler for delete all transactions */
    handleDeleteAll: () => void;
    /** Handler for download file from transaction */
    handleDownload: (transaction: Transaction, fileType: string) => void;
    /** Event handler for open QR Code for transaction */
    handleOpen: (transactionId: string) => void;
}

/**
 *  Component to render transaction table
 */
function TableComponent({
    transactions,
    skills,
    handleSkillChange,
    handleDelete,
    handleDeleteAll,
    handleDownload,
    handleOpen
}: TableComponentProperties) {
    return (
        <div className={styles.container}>
            <div className={styles.tableHeader}>
                <span>{resource.table.skill}</span>
                <span>{resource.table.fileName}</span>
                <span>{resource.table.status}</span>
                <span>
                    {transactions && transactions.allIds.length > 1 ? (
                        <span className={styles.deleteAll} onClick={handleDeleteAll}>
                            <DeleteIcon className={styles.icon} />
                            {resource.button.deleteAll}
                        </span>
                    ) : undefined}
                </span>
            </div>
            <div>
                {transactions.allIds.map((transactionUUID) => {
                    const transaction = transactions.byId[transactionUUID];
                    return (
                        <div key={transaction.uuid}>
                            <hr className={styles.hr} />
                            <TableRowComponent
                                handleOpen={handleOpen}
                                skills={skills}
                                transaction={transaction}
                                handleChange={handleSkillChange}
                                handleDelete={handleDelete}
                                handleDownload={handleDownload}
                            />
                        </div>
                    );
                })}
            </div>
        </div>
    );
}

export default TableComponent;
