import React, { useCallback } from 'react';
import { useDispatch, useSelector } from 'react-redux';
import {
    createTransactionMobileRequest,
    createTransactionRequest,
    deleteAllTransactionRequest,
    deleteTransactionRequest,
    downloadTransactionRequest,
} from '@ducks/Transaction/actions';
import TableComponent from '../components/TableComponent/TableComponent';
import { transactionsSelector } from '@ducks/Transaction/selectors/transactionsSelector';
import { Transaction } from '@api/types';
import { skillsSelector } from '@ducks/Skill/selectors/skillsSelector';
import {qrCodeShow} from "@ducks/Mobile/actions/MobileCaptureActions";

/**
 *  Container component to render transaction table
 */
function TableContainer() {
    const dispatch = useDispatch();
    const transactions = useSelector(transactionsSelector);
    const skills = useSelector(skillsSelector);

    const handleSkillChange = useCallback(
        (transaction: Transaction, skillId: string | null) => {
            if (skillId) {
                if (transaction.isMobile) {
                    dispatch(createTransactionMobileRequest({ transaction, skillId }));
                } else {
                    dispatch(createTransactionRequest({ transaction, skillId }));
                }
            }
        },
        [dispatch],
    );

    const handleDelete = useCallback(
        (transaction: Transaction) => {
            dispatch(deleteTransactionRequest({ uuid: transaction.uuid }));
        },
        [dispatch],
    );

    const handleDeleteAll = useCallback(() => {
        dispatch(deleteAllTransactionRequest());
    }, [dispatch]);

    const handleDownload = useCallback(
        (transaction: Transaction, fileId: string) => {
            dispatch(downloadTransactionRequest({ uuid: transaction.uuid, fileId }));
        },
        [dispatch],
    );

    const handleOpen = useCallback(
        (transactionId: string) => {
            dispatch(qrCodeShow({ transactionId: transactionId }));
        },
        [dispatch],
    );

    return (
        <TableComponent
            transactions={transactions}
            skills={skills}
            handleSkillChange={handleSkillChange}
            handleDelete={handleDelete}
            handleDeleteAll={handleDeleteAll}
            handleDownload={handleDownload}
            handleOpen={handleOpen}
        />
    );
}

export default TableContainer;
